function [Points, trackLength] = search_points_to_track( sGTDir, sTracksDir, iFrame, flipVideo, imgWidth )
% POINTS = SEARCH_POINTS_TO_TRACK( SDIR, IFRAME )
%   Looks inside directory SDIR for ground-truth files matching the query 
%   frame IFRAME.
%   Reads from the obtained filenames the initial x and y coordinates of 
%   the object, and stores them by row in POINTS.

frameString = sprintf('frame%.6d', iFrame); % hard-coded 6 digits
fileNameFormat = [frameString, '_x%5d_y%5d.txt']; % hard-coded 5 digits

% Look for ground-truth data corresponding to this frame
matchingFiles = dir([sGTDir, '/', frameString, '*.txt']);
numMatch = numel(matchingFiles);

Points = zeros(numMatch, 2);
trackLength = zeros(numMatch, 1);
for iFile = 1:numMatch
    % Read coordinates
    pXY = sscanf(matchingFiles(iFile).name, fileNameFormat);
    Points(iFile,2) = pXY(2);
    % Flip x coordinate
    if flipVideo
        Points(iFile,1) = imgWidth + 1 - pXY(1);
    else
        Points(iFile,1) = pXY(1);
    end  
    % Get track length
    [dummy, trackLength(iFile)] = annotation.read_annotated_track(...
        [sGTDir, '/',matchingFiles(iFile).name]);
end

% Remove those points that have already been processed
iCount = 1;
while iCount <= size(Points, 1)
    
    if annotation.check_track_exist_and_complete(sTracksDir, iFrame, Points(iCount,1), Points(iCount,2), trackLength(iCount))
    %if annotation.check_track_exist(sTracksDir, iFrame, Points(iCount,1), Points(iCount,2))
        Points(iCount,:) = [];
        trackLength(iCount) = [];
    else 
        iCount = iCount + 1;
    end
end

end

