function outputList = get_matching_files( sDir, token, varargin )
% GET_MATCHING_FILES Searches sDir for files matching the token, 
% e.g. token = '*.avi'. 
% Optional argument: string 'noR' for no recuersion.
% Returns nx2 cell with paths to subfolders and filenames.

recur = true;
if numel(varargin) > 0
    if strcmp('noR', varargin{1})
        recur = false;
    end
end

outputList = get_matching_files_(sDir, token, cell(0,2), recur);

end


function outputList = get_matching_files_( sDir, token, inputList, recur )
% GET_MATCHING_FILES Recursively searches sDir for files matching the token,
% e.g. token = '*<sVideoId>.avi'
% Returns nx2 cell with paths to subfolders and filenames.
outputList = inputList;

% Find matching files in sDir
filesHere = dir([sDir, '/', token]);
% (Exclude subfolders)
mask_dir = cell(size(filesHere));
[mask_dir{:}] = filesHere.isdir;
filesHere = filesHere( ~cell2mat(mask_dir) );
% Add to list
numFound = numel(filesHere);
if numFound ~= 0
    ln = size(outputList,1);
    for i=1:numFound
        %outputList(ln + i, 1) = cellstr(sDir);
        %outputList(ln + i, 2) = cellstr(filesHere(i).name);
        outputList(ln + i, 1:2) = {sDir, filesHere(i).name};
    end
end

if recur
    % Look recursively into subfolders
    subdirs = file_manip.get_subdirs(sDir);
    numFound = numel(subdirs);
    if numFound ~= 0
        for i=1:numFound
            outputList = get_matching_files_([sDir, '\', char(subdirs(i))], token, outputList, recur);
        end
    end
end

end

