classdef Brown
%BROWNian motion model
% Updates:
% 	new_x = old_x + noise(Xstd)
% 	new_y = old_y + noise(Ystd)
% 	new_w = old_w * (1 + noise(Sstd))
% 	new_h = old_h * (1 + samenoise(Sstd))

    properties
        % Motion model params
        Xstd = 3; 		%[-6,+6] pix 70% of time
    	Ystd = 3; 		%[-6,+6] pix 70% of time
        Sstd = 0.5/15; 	%[-1,+1] pix 70% of time (ref size 15)
        
        noiseLev = 1;	% multiplies the default standard deviations
        
        % Number of dimensions of state vector
        numDims = 5; % x, y, w, h, lastLikelihood
		
    end% properties
    
    methods
        function mm = Brown(iNoiseLev)
            if nargin < 1
                return;
            end
            mm.noiseLev = iNoiseLev;
            mm.Xstd = iNoiseLev * mm.Xstd; 
            mm.Ystd = iNoiseLev * mm.Ystd;
            mm.Sstd = iNoiseLev * mm.Sstd;
        end
        
        function particles = init_particles(mm, initMeasure, numParticles, ...
                imgWidth, imgHeight)
            initState = [initMeasure, 1]; 
            particles = repmat(initState, numParticles, 1);
        end
        
        function new_state = predict(mm, old_state)
            new_state = zeros(1, mm.numDims);
            VelXYS = [mm.Xstd, mm.Ystd, mm.Sstd ] .* randn(1,3);

            % Update state
            new_state(1:2) = old_state(1:2) + VelXYS(1:2);
            new_state(3:4) = old_state(3:4) .* (1 + VelXYS(3));
        end
        
    end% methods
   
end% classdef