classdef Bwd
    properties
        % Motion model params
        VXstd = 1;
    	VYstd = 1;
    	Astd =  pi ./ 180;
    	KDstd = 0.01;
    	KSstd = 0.005;
		
    	KD0 = 0.99; % prior change in distance
    	KS0 = 0.995; % prior change in scale
        VX = 0.5;
        VY = 0.5;
        fact = 4; % centricity of vp-coordinate priors
		
        noiseLev = 1;	% multiplies the default standard deviations.
        
		initNoise = 4;	% multiplies the default standard deviations, 
						% ony for initialization of the latent variables.
						
        % Number of dimensions of state vector
        numDims = 9; % x, y, w, h, Kd, Ks, Vx, Vy, lastLikelihood
        
    end% properties
    methods
        
        function mm = Bwd(iNoiseLev) %ctor
            if nargin < 1
                return;
            end
            mm.noiseLev = iNoiseLev;
            mm.VXstd = iNoiseLev * mm.VXstd; 
            mm.VYstd = iNoiseLev * mm.VYstd;
            mm.Astd = iNoiseLev * mm.Astd;
            mm.KDstd = iNoiseLev * mm.KDstd;
            mm.KSstd = iNoiseLev * mm.KSstd;
        end% function
        
        function particles = init_particles(mm, initMeasure, numParticles, ...
                imgWidth, imgHeight)
            
            initState = [initMeasure, mm.KD0, mm.KS0, ...
                mm.VX .* imgWidth, mm.VY .* imgHeight, 1];
            
			% Obtain several priors for the vanishing point (North, South, East, West, Center)
            modes = motion_models.Bwd.get_vp_modes(numParticles, 1 ./ mm.fact);
            modes(:,1) = modes(:,1) .* imgWidth;
            modes(:,2) = modes(:,2) .* imgHeight;
            
            kdNoise = randn(numParticles, 1);
            ksNoise = kdNoise + 0.1 .* randn(numParticles, 1);
  
            particles = repmat(initState, numParticles, 1) + ...
                [zeros(numParticles,4), ... % known initial state
                mm.initNoise .* mm.KDstd .* kdNoise, ... % noise on prior KD
                mm.initNoise .* mm.KSstd .* ksNoise, ... % noise on prior KS
                mm.initNoise .* mm.VXstd .* randn(numParticles,1) + modes(:,1), ... % noise in Vx coordinate
                mm.initNoise .* mm.VYstd .* randn(numParticles,1) + modes(:,2), ... % noise in Vy coordinate
                zeros(numParticles,1)];
        end
        
        function new_state = predict(mm, old_state)
            new_state = zeros(1, mm.numDims);

            tf = 1;

            % Sample vanishing point from previous (nearly fixed, because VXstd and VYstd are low)
            Vp = old_state(7:8) + tf .* [mm.VXstd, mm.VYstd] .* randn(1,2);

            % Get coordinates relative to this vanishing point
            relXY = (old_state(1:2) - Vp)';

            % Sample angular deviation and update relative coordinates (apply rotation)
            alpha = mm.Astd .* randn(1,1);
            upRelXY = [cos(alpha), -sin(alpha); sin(alpha), cos(alpha)] * relXY;

            % Sample Kd and Ks (same "side" of the Gaussian)
            randomSample1 = randn(1,1);
            randomSample2 = randomSample1 + 0.1 .* randn(1,1);
            Kd = old_state(5) + tf .* mm.KDstd .* randomSample1;
            Ks = old_state(6) + tf .* mm.KSstd .* randomSample2;

            % Update state
            new_state(1:2) = Kd .* upRelXY' + Vp; % X, Y
            new_state(3:4) = Ks .* old_state(3:4); % W, H
            new_state(5) = Kd;
            new_state(6) = Ks;
            new_state(7) = Vp(1);
            new_state(8) = Vp(2);
        end
        
    end% methods
    
    methods (Access = private, Static)
        function modes = get_vp_modes(numParticles, rad)
            % Five modes: Center, North, South, Esat, West, at +/- rad
            n = 5;
            idx = floor(rand(numParticles,1) .* n);
            angle = idx.*(pi/2);
            modes = [rad .* cos(angle), rad .* sin(angle)];
            modes(idx < (n-4), 1) = 0;
            modes(idx < (n-4), 2) = 0;
        end 
    end
end% classdef