classdef TruckL
%TRUCKingLeft motion model CORRECTED
% Updates:
% 	new_x = old_x + old_velX + noise(Xstd)
% 	new_y = old_y + old_velY + noise(Ystd)
% 	new_w = old_w * (old_velS + noise(Sstd))
% 	new_h = old_h * (old_velS + samenoise(Sstd))
% Characteristics:
% 	Negative prior on velX
% 	Small std dev for velY and velS

    properties
        % Motion model params
        Xstd = 1; 		%[-2,+2] pix 70% of time
    	Ystd = 0.1; 	%[-0.2,+0.2] pix 70% of time
        Sstd = 0.1/15; 	%[-0.2,+0.2] pix 70% of time (ref size 15)
		
		velX0 = 2; 	% prior
		velY0 = 0; 		% prior
		velS0 = 1; 		% prior
    	
        noiseLev = 1;   % multiplies the default standard deviations.
		initNoise = 4;	% multiplies the default standard deviations, 
						% ony for initialization of the latent variables.
						
        % Number of dimensions of state vector
        numDims = 8; 	% x, y, w, h, velx, vely, velS, lastLikelihood
		
    end% properties
    
    methods
        
        function mm = TruckL(iNoiseLev) %ctor
            if nargin < 1
                return;
            end
            mm.noiseLev = iNoiseLev;
            mm.Xstd = iNoiseLev * mm.Xstd; 
            mm.Ystd = iNoiseLev * mm.Ystd;
            mm.Sstd = iNoiseLev * mm.Sstd;
           
        end% function
        
        function particles = init_particles(mm, initMeasure, numParticles, ...
                imgWidth, imgHeight)
            
            initState = [initMeasure, mm.noiseLev*mm.initNoise*mm.velX0, mm.velY0, mm.velS0, 1]; 
           
            particles = repmat(initState, numParticles, 1) + ...
                [zeros(numParticles,4), ... % known initial state
                mm.initNoise .* mm.Xstd .* randn(numParticles,1), ... % noise on prior
                mm.initNoise .* mm.Ystd .* randn(numParticles,1), ...
				mm.initNoise .* mm.Sstd .* randn(numParticles,1),...
                zeros(numParticles,1)];
        end
        
        function new_state = predict(mm, old_state)
            new_state = zeros(1, mm.numDims);
            VelXYS = old_state(5:7) + [mm.Xstd, mm.Ystd, mm.Sstd ] .* randn(1,3);

            % Update state
            new_state(1:2) = old_state(1:2) + VelXYS(1:2);
            new_state(3:4) = old_state(3:4) .* VelXYS(3);
            new_state(5:7) = VelXYS;
        end
        
    end% methods
    
   
end% classdef