function compute_heuristic_on_video(videoID, sDirTracks, sFnameOutput)
%Weighted lenght. Heuristic of the quality of the tracking.

global logfid

% ---------------
% Hard-coded info
% ---------------
% File containing the tracking results has this name format:
nameFormat = 'mm %s nl %f'; % see line 39

% ------------------
% Process this video
% ------------------

% Tracking performances (heuristic) for the different tracking strategies:
trackWLengths = struct('model', {}, 'param', {}, 'wLength', {}, 'meanQual', {});

% Look for folders containing tracking results
list = file_manip.get_matching_dirs(sDirTracks, 'mm*'); %see name format line 17
stratsInDir = list(:,2);


% Display number of strategies found in the directory
display(['Processing ', videoID, ': ', num2str(numel(stratsInDir)), ' tracking strategies found']);

for stg = 1:numel(stratsInDir)
    % Which model and params
    scanResult = textscan(stratsInDir{stg}, nameFormat, 'Delimiter', '_');
    trackWLengths(stg).model = char(scanResult{1});
    trackWLengths(stg).param = scanResult{2};

    % Get tracked points
    fullDir = [sDirTracks,'/', stratsInDir{stg}];
    trackedPoints = file_manip.get_matching_files(fullDir, '*.mat', 'noR');
    trackedPointsFnames = trackedPoints(:,2);    
    
    % Allocate outputs
    trackWLengths(stg).wLength = zeros(...
        numel(trackedPointsFnames),1);
   
    % Get quality for each point
    for iPoint = 1:numel(trackedPointsFnames)
        baseName = strtok( trackedPointsFnames{iPoint}, '.');
        try
            load([fullDir,'/',baseName,'.mat'], 'track');
        catch em
            fprintf(logfid, ['\n',em.message, '\n']);
            continue; 
        end

        trackWLengths(stg).wLength(iPoint) = ...
            get_heuristic([fullDir,'/',baseName,'.mat']);
    end

    % Report out result (average over the number of tracked points)
    trackWLengths(stg).meanQual = mean(trackWLengths(stg).wLength);

end % end num of strategies used in this video

% Save perfos for this video (all motion strategies)
save([sDirTracks,'/', sFnameOutput, '.mat'], 'trackWLengths');
    
end



