% script_compute_heuristic.m
%
% Process all track files for all videos.
% For each video, produce a file with a score for each tracking 
% strategy (motion model + noise parameter), based on the length of the
% produced tracks.

global logfid

% Data folder
dataDir = 'F:/data/tracking';

% Name of the run to analyze
tag = 'run001';

% Log and output files
logfid = fopen(['log_', datestr(now, 'yyyy-mm-dd-HH-MM-SS'), '_heuristic', tag, '.txt'], 'w');
ofid = fopen(['heuristic_table_', tag, '.txt'], 'w');

% Obtain list of videos
fid = fopen('all_labels_enlarged.txt');
A = textscan(fid, '%s %s', 'Delimiter', ' \t');
fclose(fid);
names = A{1};
labels = A{2};
numVideos = size(names,1);


% Print header
titles = {'Br', 'CVel', 'TRight', 'TLeft', 'Fwd', 'Bwd'};
fprintf(ofid, '\t');
for mm = 1:numel(titles)
    fprintf(ofid, '%s\t', titles{mm});
end
fprintf(ofid, '\n');


for vid = 1:numVideos
    videoID = names{vid};
	dirTracks = [dataDir, '/tracks/', videoID, '/' videoID, 'Tracks', tag];
    
    % Evaluate the tracks according to a track-length heuristic
    fnameOut = ['heuristic_', tag];
    compute_heuristic_on_video(videoID, dirTracks, fnameOut);
    
    % Compare heuristic for each motion model
    tmp = load([dirTracks,'/', fnameOut, '.mat'], 'trackWLengths');
    trackWLengths = tmp.trackWLengths;
    clear tmp;
    scores = select_heuristic({'brown', 'const', 'tkr', 'tkl', 'fwd', 'bwd'}, trackWLengths);
    
    % Print the row of scores for this video
    fprintf(ofid, '%s\t', videoID);
    fprintf(ofid, '%f\t', scores(1,:));
    fprintf(ofid, '\n');
    
    
end

fclose all;
