% script_compute_tracking_perfo.m
%
% Process all track files for all videos.
% For each video, produce a file with the performance of each tracking 
% strategy (motion model + noise parameter), wrt to the ground-truth
% track landmarks.

global logfid

dataDir = 'F:/data/tracking';

% A name for this run
tag = 'run001';  %'1k'; %'run002';

% Whether to skip or overwrite exising results
resume = true;

% Log file
logfid = fopen(['log_', datestr(now, 'yyyy-mm-dd-HH-MM-SS'), '_', tag, '.txt'], 'w');

% Obtain list of videos
fid = fopen('all_labels_enlarged.txt');
A = textscan(fid, '%s %s', 'Delimiter', ' \t');
names = A{1};
labels = A{2};
numVideos = size(names,1);



for vid = 1:numVideos
    videoID = names{vid};
    
    % These directories must match those in track_video.m
	dirTracks = [dataDir, '/tracks/', videoID, '/' videoID, 'Tracks', tag];
	dirGT = [dataDir, '/GT_tracks/', videoID, '/' videoID, 'Data'];
    fnameOut = ['results_track_', tag];
    
	compute_tracking_perfo_on_video(videoID, dirTracks, dirGT, fnameOut, resume);
end

fclose all;
