% script_print_all_videos_table.m
%
% Takes result from script_compute_tracking_perfo and print table in
% text format

global logfid

dataDir = 'F:/data/tracking';

% The name of the run to be processed
%trackTags = {'run001'}; %{'run001', 'run002'};
%tag = cell2mat(trackTags);
tag = 'run001'; 

motion_models = {'brown', 'const', 'tkr', 'tkl', 'fwd', 'bwd'};
titles = motion_models; %{'Br', 'CVel', 'TRight', 'TLeft', 'Fwd', 'Bwd'};

scoreType = 'default';

keyName = [tag, '_', scoreType];
fid = fopen(['results_table_', keyName , '.txt'], 'w');
logfid = fopen(['log_', datestr(now, 'yyyy-mm-dd-HH-MM-SS'), '_printing_', keyName, '.txt'], 'w');

% Get video IDs
iFid = fopen('all_labels_enlarged.txt');
A = textscan(iFid, '%s %s', 'Delimiter', ' \t');
fclose(iFid);
videosToRun = A{1};
labels = A{2};
numVideos = size(videosToRun,1);
clear iFid A

% Print header
fprintf(fid, '\t');
for mm = 1:numel(titles)
    fprintf(fid, '%s\t', titles{mm});
end
fprintf(fid, '\n');


for iVid = 1:numVideos
    
    videoID = videosToRun{iVid};
    display(videoID);
    
    % Get file with the performance of each tracking strategy
    
    % This directory and fname must match those in script_compute_tracking_perfo.m
    resultsDir = [dataDir, '/tracks/', videoID, '/' videoID, 'Tracks', tag];
    token = ['results_track_', tag, '.mat'];
    matchingFiles = file_manip.get_matching_files(resultsDir, token );
    if size(matchingFiles,1) ~= 1
        fprintf(logfid, ['\n', videoID, ': Problem looking for ', token, ' in ', resultsDir, '\n']);
        continue;
    end
    try
        fname = [matchingFiles{1,1}, '/', matchingFiles{1,2}];
        tmp = load(fname, 'trackStrats');
        trackStrats = tmp.trackStrats;
        clear tmp;
    catch eM
        fprintf(logfid, ['\n', videoID, ': Problem opening ', fname '\n', eM.message, '\n']);
        continue;
    end
    try
        [scores, ok] = select_perfo(motion_models, trackStrats, scoreType);
    catch eM
        fprintf(logfid, ['\n', videoID, ': Problem computing score\n', eM.message, '\n']);
        continue;
    end
    
%     % Little sanity check for default param and several runs
%     
%     if numel(trackTags) > 1
%         partialScores = zeros(numel(trackTags), numel(motion_models));
%         for iTag = 1:numel(trackTags)
%             match = file_manip.get_matching_files(videoDir, ['results_track', trackTags{iTag}, '.mat'] );
%             fname = [matchingFiles{1,1}, '/', matchingFiles{1,2}];
%             tmp = load([match{1,1}, '/', match{1,2}], 'trackStrats');
%             partialTrackStrats = tmp.trackStrats;
%             partialScores(iTag,:) = select_perfo(motion_models, partialTrackStrats, scoreType);
%         end
%         avg = mean(partialScores,1);
%         if sum(abs(avg-scores) > 0.00001) > 0
%             display avg;
%             display scores;
%             fprintf(logfid, ['\n', videoID, ': Mismatching scores [', num2str(avg), '] vs. [', num2str(scores), ']\n']);
%         end
%     end
    
    % Print the row of scores for this video
    fprintf(fid, '%s\t', videoID);
    fprintf(fid, '%f\t', scores(1,:));
    fprintf(fid, '\n');
    
end

fclose all;

