function scores = select_heuristic(motion_models, trackWLengths)

defaultParam = 1;

% Output
scores = zeros(1, numel(motion_models)); % one score per motion model
ok = true;
perfo = {};
sorted_params = {};

% For each motion model
for mm = 1:numel(motion_models)
 
    % Group all the motion strategies corresponding to THE SAME motion
    % model (different parameters)
    numTrackStrats = numel(trackWLengths);
    tmpvar = cell(1,numTrackStrats);
    ct_val = motion_models(mm);
    tmpvar(1:numTrackStrats) = ct_val;
    match = cellfun(@strcmp,{trackWLengths(1,:).model},tmpvar);
   
    if numel(match) <= 0
        display([motion_models{mm}, ': No matching elements found']);
        scores(mm) = -1;
        ok = false;
        continue;
    end
    
    matchWLenghts = trackWLengths(1,match);
    %(matchStrat contains only the elements that match the given
    % motion model, e.g. brownian)
    
    % Sort the parameter values
    [sortedParams, sortidx] = sort(cell2mat({matchWLenghts(1,:).param}));
    numParams = length(sortidx);
    
    display([motion_models{mm}, ': ', num2str(numParams), ' parameters found']);

    % Get average results (over all tracked points) for this video
    scores(1, mm) = matchWLenghts(sortidx(sortedParams == defaultParam)).meanQual;
    
end


end


